import "pe"

rule EXE_Stealer_StealC_Feb2024 {
    meta:
        Description = "Detects Stealc malware samples based on PE properties"
        author = "Yashraj Solanki - Cyber Threat Intelligence Analyst at Bridewell"
        Reference = "https://bazaar.abuse.ch/browse/signature/Stealc/"
        Hash = "2b9d440e0a2b6b641c148826946d60bb71a28f866922b05847548563708b4450"
        Sample_Test = "Tested against 5 Stealc samples and the broader malware collection"
        date = "2024-02-08"
        yarahub_author_twitter = "@RustyNoob619"
        yarahub_reference_md5 = "7a5c8f91ebcb37887631254be023767c"
        yarahub_uuid = "bc223415-d3da-4e55-a439-12a41079ca6f"
        yarahub_license = "CC0 1.0"
        yarahub_rule_matching_tlp = "TLP:WHITE"
        yarahub_rule_sharing_tlp = "TLP:WHITE"
        malpedia_family = "win.stealc"
    condition:
        filesize < 1MB
        and pe.pdb_path endswith ".pdb"
        and pe.import_details[0].number_of_functions > 80
        and for any entity in pe.import_details:
        ((entity.library_name == "GDI32.dll"
            or entity.library_name == "WINHTTP.dll"
            or entity.library_name == "ADVAPI32.dll")
        and entity.number_of_functions == 1) //looking for specific Dlls with one import function only
        and for any resource in pe.resources:
        (resource.language == 1048  or resource.language == 2137) //Checking for Romanian or Sindhi Sys Default languages 
       
 }
