rule EXPLOIT_WinRAR_CVE_2023_38831_Aug23 {
    meta:
        version = "1.0"
        date = "2023-08-23"
        modified = "2023-08-23"
        status = "RELEASED"
        sharing = "TLP:CLEAR"
        source = "SECUINFRA Falcon Team"
        author = "Marius Genheimer @ Falcon Team"
        description = "Detects ZIP archives potentially exploiting CVE-2023-38831 in WinRAR"
        category = "EXPLOIT"
        mitre_att = "T1203"
        actor_type = "CRIMEWARE"
        reference = "https://www.group-ib.com/blog/cve-2023-38831-winrar-zero-day"
        minimum_yara = "4.2"
        hash0 = "43f5eb815eed859395614a61251797aa777bfb694a9ef42fbafe058dff84d158"
        hash1 = "61c15d6a247fbb07c9dcbce79285f7f4fcc45f806521e86a2fc252a311834670"
        hash2 = "2010a748827129b926cf3e604b02aa77f5a7482da2a15350504d252ee13c823b"
        hash3 = "bfb8ca50a455f2cd8cf7bd2486bf8baa950779b58a7eab69b0c151509d157578"
        yarahub_uuid = "67176e05-1858-4ff4-ad4b-154f549ec5d4"
        yarahub_reference_md5 = "3a7ad5fdfc9e51c4ee5df425169add1a"
        yarahub_license = "CC BY 4.0"
        yarahub_rule_matching_tlp = "TLP:WHITE"
        yarahub_rule_sharing_tlp = "TLP:WHITE"
        yarahub_author_twitter = "@SI_FalconTeam"

    strings:
        $kw_1 = "Trade" nocase ascii
        $kw_2 = "Trading" nocase ascii
        $kw_3 = "Strategy" nocase ascii
        $kw_4 = "Strategies" nocase ascii
        $kw_5 = "Screenshot" nocase ascii
        $kw_6 = "Indicator" nocase ascii

        $doubleext_cmd = {2E ?? ?? ?? 20 2E 63 6D 64}
        $doubleext_bat = {2E ?? ?? ?? 20 2E 62 61 74}
        $doubleext_vbs = {2E ?? ?? ?? 20 2E 76 62 73}
        $doubleext_wsf = {2E ?? ?? ?? 20 2E 77 73 66}
        $doubleext_wsh = {2E ?? ?? ?? 20 2E 77 73 68}
        $doubleext_ps1 = {2E ?? ?? ?? 20 2E 70 73 31}
        $doubleext_js = {2E ?? ?? ?? 20 2E 6A 73}

        $s_ico = ".ico" ascii

    condition:
        uint16(0) == 0x4B50
        and (any of ($kw_*) or none of ($kw_*))
        and any of ($doubleext_*)
        and #s_ico >= 1
}